

#load R/qtl

library(qtl)

# See http://www.rqtl.org/ for more info

# Reading in the data from the Norway site:

NorSpMa <- read.cross("csv", dir="","AlyrataSpMaNorway.csv",na.strings = "NA",genotypes=NULL,sep=";")
# Summarize data set:
summary (NorSpMa)

#### GENOTYPE PROBABILITIES ####

# Calculate genotype probabilities and add to file:
NorSpMa <- calc.genoprob(NorSpMa , step=2, off.end=0, error.prob=0.001,
  map.function="kosambi", stepwidth="fixed")

#### SIMULATED GENOTYPES ####

#  Simulate genotypes (allows use of pseudomarkers in effects plot:
NorSpMa <- sim.geno(NorSpMa , n.draws=128, step=2, off.end=0, error.prob=0.001,
  map.function="kosambi", stepwidth="fixed")

Cross <- pull.pheno(NorSpMa, "Cytop")

# GENOME-WIDE QTL ANALYSIS RUNS
# scanone and permutations
# A different set of digits into seednum has been used for each trait

#CUMULATIVE SURVIVAL OVER 1st WINTER

# Setting the seed value:
seednum <- 287529813

# Running permutations for two models with identical seed values:
set.seed(seednum)
SurvWin1.Cross.PermAC <- scanone(NorSpMa, pheno.col="SurvWin1",
  model="binary", method="em", addcovar=Cross, n.perm=1000)
ACthresh <- summary(SurvWin1.Cross.PermAC, alpha=c(0.05,0.10))
set.seed(seednum)
SurvWin1.Cross.PermIC <- scanone(NorSpMa, pheno.col="SurvWin1",
  model="binary", method="em", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(SurvWin1.Cross.PermIC, alpha=c(0.05,0.10))

# The following makes a data frame with the differences in the lods from the 
# corresponding permutations, and runs summary to get difference threshold:
SurvWin1.Cross.PermDiff <- SurvWin1.Cross.PermIC - SurvWin1.Cross.PermAC
summary(SurvWin1.Cross.PermDiff)

# This runs scanone to map QTLs under additive and interactive models:
SurvWin1.Cross.ScanAC <- scanone(NorSpMa, pheno.col="SurvWin1", model="binary",
  method="em", addcovar=Cross)
summary(SurvWin1.Cross.ScanAC, perm=SurvWin1.Cross.PermAC, df=TRUE)
SurvWin1.Cross.ScanIC <- scanone(NorSpMa, pheno.col="SurvWin1", model="binary",
  method="em", addcovar=Cross, intcovar=Cross)
summary(SurvWin1.Cross.ScanIC, perm=SurvWin1.Cross.PermIC, df=TRUE)

#CUMULATIVE SURVIVAL OVER 2nd WINTER
seednum <- 287529803
set.seed(seednum)
SurvWin2.Cross.PermAC <- scanone(NorSpMa, pheno.col="SurvWin2",
  model="binary", method="em", addcovar=Cross, n.perm=1000)
ACthresh <- summary(SurvWin2.Cross.PermAC, alpha=c(0.05,0.10))
set.seed(seednum)
SurvWin2.Cross.PermIC <- scanone(NorSpMa, pheno.col="SurvWin2",
  model="binary", method="em", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(SurvWin2.Cross.PermIC, alpha=c(0.05,0.10))
SurvWin2.Cross.PermDiff <- SurvWin2.Cross.PermIC - SurvWin2.Cross.PermAC
summary(SurvWin2.Cross.PermDiff)
SurvWin2.Cross.ScanAC <- scanone(NorSpMa, pheno.col="SurvWin2", model="binary",
  method="em", addcovar=Cross)
summary(SurvWin2.Cross.ScanAC, perm=SurvWin2.Cross.PermAC, df=TRUE)
SurvWin2.Cross.ScanIC <- scanone(NorSpMa, pheno.col="SurvWin2", model="binary",
  method="em", addcovar=Cross, intcovar=Cross)
summary(SurvWin2.Cross.ScanIC, perm=SurvWin2.Cross.PermIC, df=TRUE)

#CUMULATIVE SURVIVAL OVER 3rd WINTER
seednum <- 354789412
set.seed(seednum)
SurvWin3.Cross.PermAC <- scanone(NorSpMa, pheno.col="SurvWin3",
  model="binary", method="em", addcovar=Cross, n.perm=1000)
ACthresh <- summary(SurvWin3.Cross.PermAC, alpha=c(0.05,0.10))
set.seed(seednum)
SurvWin3.Cross.PermIC <- scanone(NorSpMa, pheno.col="SurvWin3",
  model="binary", method="em", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(SurvWin3.Cross.PermIC, alpha=c(0.05,0.10))
SurvWin3.Cross.PermDiff <- SurvWin3.Cross.PermIC - SurvWin3.Cross.PermAC
summary(SurvWin3.Cross.PermDiff)
SurvWin3.Cross.ScanAC <- scanone(NorSpMa, pheno.col="SurvWin3", model="binary",
  method="em", addcovar=Cross)
summary(SurvWin3.Cross.ScanAC, perm=SurvWin3.Cross.PermAC, df=TRUE)
SurvWin3.Cross.ScanIC <- scanone(NorSpMa, pheno.col="SurvWin3", model="binary",
  method="em", addcovar=Cross, intcovar=Cross)
summary(SurvWin3.Cross.ScanIC, perm=SurvWin3.Cross.PermIC, df=TRUE)

#CUMULATIVE SURVIVAL OVER 4th WINTER

seednum <- 568745644
set.seed(seednum)
SurvWin4.Cross.PermAC <- scanone(NorSpMa, pheno.col="SurvWin4",
  model="binary", method="em", addcovar=Cross, n.perm=1000)
ACthresh <- summary(SurvWin4.Cross.PermAC, alpha=c(0.05,0.10))
set.seed(seednum)
SurvWin4.Cross.PermIC <- scanone(NorSpMa, pheno.col="SurvWin4",
  model="binary", method="em", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(SurvWin4.Cross.PermIC, alpha=c(0.05,0.10))
SurvWin4.Cross.PermDiff <- SurvWin4.Cross.PermIC - SurvWin4.Cross.PermAC
summary(SurvWin4.Cross.PermDiff)
SurvWin4.Cross.ScanAC <- scanone(NorSpMa, pheno.col="SurvWin4", model="binary",
  method="em", addcovar=Cross)
summary(SurvWin4.Cross.ScanAC, perm=SurvWin4.Cross.PermAC, df=TRUE)
SurvWin4.Cross.ScanIC <- scanone(NorSpMa, pheno.col="SurvWin4", model="binary",
  method="em", addcovar=Cross, intcovar=Cross)
summary(SurvWin4.Cross.ScanIC, perm=SurvWin4.Cross.PermIC, df=TRUE)

#CUMULATIVE SURVIVAL OVER 5th WINTER

seednum <- 547877562
set.seed(seednum)
SurvWin5.Cross.PermAC <- scanone(NorSpMa, pheno.col="SurvWin5",
  model="binary", method="em", addcovar=Cross, n.perm=1000)
ACthresh <- summary(SurvWin5.Cross.PermAC, alpha=c(0.05,0.10))
set.seed(seednum)
SurvWin5.Cross.PermIC <- scanone(NorSpMa, pheno.col="SurvWin5",
  model="binary", method="em", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(SurvWin5.Cross.PermIC, alpha=c(0.05,0.10))
SurvWin5.Cross.PermDiff <- SurvWin5.Cross.PermIC - SurvWin5.Cross.PermAC
summary(SurvWin5.Cross.PermDiff)
SurvWin5.Cross.ScanAC <- scanone(NorSpMa, pheno.col="SurvWin5", model="binary",
  method="em", addcovar=Cross)
summary(SurvWin5.Cross.ScanAC, perm=SurvWin5.Cross.PermAC, df=TRUE)
SurvWin5.Cross.ScanIC <- scanone(NorSpMa, pheno.col="SurvWin5", model="binary",
  method="em", addcovar=Cross, intcovar=Cross)
summary(SurvWin5.Cross.ScanIC, perm=SurvWin5.Cross.PermIC, df=TRUE)

#FLOWERING PROPENSITY - 1ST YEAR
seednum <- 287777803
set.seed(seednum)
Flow1.Cross.PermAC <- scanone(NorSpMa, pheno.col="Flow1",
  model="binary", method="em", addcovar=Cross, n.perm=1000)
ACthresh <- summary(Flow1.Cross.PermAC, alpha=c(0.05,0.10))
set.seed(seednum)
Flow1.Cross.PermIC <- scanone(NorSpMa, pheno.col="Flow1",
  model="binary", method="em", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(Flow1.Cross.PermIC, alpha=c(0.05,0.10))
Flow1.Cross.PermDiff <- Flow1.Cross.PermIC - Flow1.Cross.PermAC
summary(Flow1.Cross.PermDiff)
Flow1.Cross.ScanAC <- scanone(NorSpMa, pheno.col="Flow1", model="binary",
  method="em", addcovar=Cross)
summary(Flow1.Cross.ScanAC, perm=Flow1.Cross.PermAC, df=TRUE)
Flow1.Cross.ScanIC <- scanone(NorSpMa, pheno.col="Flow1", model="binary",
  method="em", addcovar=Cross, intcovar=Cross)
summary(Flow1.Cross.ScanIC, perm=Flow1.Cross.PermIC, df=TRUE)

#FLOWERING PROPENSITY - 2ND YEAR

seednum <- 546543213
set.seed(seednum)
Flow2.Cross.PermAC <- scanone(NorSpMa, pheno.col="Flow2",
  model="binary", method="em", addcovar=Cross, n.perm=1000)
ACthresh <- summary(Flow2.Cross.PermAC, alpha=c(0.05,0.10))
set.seed(seednum)
Flow2.Cross.PermIC <- scanone(NorSpMa, pheno.col="Flow2",
  model="binary", method="em", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(Flow2.Cross.PermIC, alpha=c(0.05,0.10))
Flow2.Cross.PermDiff <- Flow2.Cross.PermIC - Flow2.Cross.PermAC
summary(Flow2.Cross.PermDiff)
Flow2.Cross.ScanAC <- scanone(NorSpMa, pheno.col="Flow2", model="binary",
  method="em", addcovar=Cross)
summary(Flow2.Cross.ScanAC, perm=Flow2.Cross.PermAC, df=TRUE)
Flow2.Cross.ScanIC <- scanone(NorSpMa, pheno.col="Flow2", model="binary",
  method="em", addcovar=Cross, intcovar=Cross)
summary(Flow2.Cross.ScanIC, perm=Flow2.Cross.PermIC, df=TRUE)

#FLOWERING PROPENSITY - 3RD YEAR

seednum <- 458546654
set.seed(seednum)
Flow3.Cross.PermAC <- scanone(NorSpMa, pheno.col="Flow3",
  model="binary", method="em", addcovar=Cross, n.perm=1000)
ACthresh <- summary(Flow3.Cross.PermAC, alpha=c(0.05,0.10))
set.seed(seednum)
Flow3.Cross.PermIC <- scanone(NorSpMa, pheno.col="Flow3",
  model="binary", method="em", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(Flow3.Cross.PermIC, alpha=c(0.05,0.10))
Flow3.Cross.PermDiff <- Flow3.Cross.PermIC - Flow3.Cross.PermAC
summary(Flow3.Cross.PermDiff)
Flow3.Cross.ScanAC <- scanone(NorSpMa, pheno.col="Flow3", model="binary",
  method="em", addcovar=Cross)
summary(Flow3.Cross.ScanAC, perm=Flow3.Cross.PermAC, df=TRUE)
Flow3.Cross.ScanIC <- scanone(NorSpMa, pheno.col="Flow3", model="binary",
  method="em", addcovar=Cross, intcovar=Cross)
summary(Flow3.Cross.ScanIC, perm=Flow3.Cross.PermIC, df=TRUE)

#FLOWERING PROPENSITY - 4TH YEAR

seednum <- 653548545
set.seed(seednum)
Flow4.Cross.PermAC <- scanone(NorSpMa, pheno.col="Flow4",
  model="binary", method="em", addcovar=Cross, n.perm=1000)
ACthresh <- summary(Flow4.Cross.PermAC, alpha=c(0.05,0.10))
set.seed(seednum)
Flow4.Cross.PermIC <- scanone(NorSpMa, pheno.col="Flow4",
  model="binary", method="em", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(Flow4.Cross.PermIC, alpha=c(0.05,0.10))
Flow4.Cross.PermDiff <- Flow4.Cross.PermIC - Flow4.Cross.PermAC
summary(Flow4.Cross.PermDiff)
Flow4.Cross.ScanAC <- scanone(NorSpMa, pheno.col="Flow4", model="binary",
  method="em", addcovar=Cross)
summary(Flow4.Cross.ScanAC, perm=Flow4.Cross.PermAC, df=TRUE)
Flow4.Cross.ScanIC <- scanone(NorSpMa, pheno.col="Flow4", model="binary",
  method="em", addcovar=Cross, intcovar=Cross)
summary(Flow4.Cross.ScanIC, perm=Flow4.Cross.PermIC, df=TRUE)

#FLOWERING PROPENSITY - 5TH YEAR

seednum <- 672184556
set.seed(seednum)
Flow5.Cross.PermAC <- scanone(NorSpMa, pheno.col="Flow5",
  model="binary", method="em", addcovar=Cross, n.perm=1000)
ACthresh <- summary(Flow5.Cross.PermAC, alpha=c(0.05,0.10))
set.seed(seednum)
Flow5.Cross.PermIC <- scanone(NorSpMa, pheno.col="Flow5",
  model="binary", method="em", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(Flow5.Cross.PermIC, alpha=c(0.05,0.10))
Flow5.Cross.PermDiff <- Flow5.Cross.PermIC - Flow5.Cross.PermAC
summary(Flow5.Cross.PermDiff)
Flow5.Cross.ScanAC <- scanone(NorSpMa, pheno.col="Flow5", model="binary",
  method="em", addcovar=Cross)
summary(Flow5.Cross.ScanAC, perm=Flow5.Cross.PermAC, df=TRUE)
Flow5.Cross.ScanIC <- scanone(NorSpMa, pheno.col="Flow5", model="binary",
  method="em", addcovar=Cross, intcovar=Cross)
summary(Flow5.Cross.ScanIC, perm=Flow5.Cross.PermIC, df=TRUE)

#NUMBER OF INFLORESCENCE SHOOTS - 1ST YEAR

seednum <- 566744844
set.seed(seednum)
TotSh1.Cross.PermAC <- scanone(NorSpMa, pheno.col="TotSh1",
  model="normal", method="hk", addcovar=Cross, n.perm=1000)
ACthresh <- summary(TotSh1.Cross.PermAC, alpha=c(0.05,0.10))
set.seed(seednum)
TotSh1.Cross.PermIC <- scanone(NorSpMa, pheno.col="TotSh1",
  model="normal", method="hk", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(TotSh1.Cross.PermIC, alpha=c(0.05,0.10))
TotSh1.Cross.PermDiff <- TotSh1.Cross.PermIC - TotSh1.Cross.PermAC
summary(TotSh1.Cross.PermDiff)
TotSh1.Cross.ScanAC <- scanone(NorSpMa, pheno.col="TotSh1", model="normal",
  method="hk", addcovar=Cross)
summary(TotSh1.Cross.ScanAC, perm=TotSh1.Cross.PermAC, df=TRUE)
TotSh1.Cross.ScanIC <- scanone(NorSpMa, pheno.col="TotSh1", model="normal",
  method="hk", addcovar=Cross, intcovar=Cross)
summary(TotSh1.Cross.ScanIC, perm=TotSh1.Cross.PermIC, df=TRUE)

#NUMBER OF INFLORESCENCE SHOOTS - 2ND YEAR

seednum <- 997354226
set.seed(seednum)
TotSh2.Cross.PermAC <- scanone(NorSpMa, pheno.col="TotSh2",
  model="normal", method="hk", addcovar=Cross, n.perm=1000)
ACthresh <- summary(TotSh2.Cross.PermAC, alpha=c(0.05,0.10))
set.seed(seednum)
TotSh2.Cross.PermIC <- scanone(NorSpMa, pheno.col="TotSh2",
  model="normal", method="hk", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(TotSh2.Cross.PermIC, alpha=c(0.05,0.10))
TotSh2.Cross.PermDiff <- TotSh2.Cross.PermIC - TotSh2.Cross.PermAC
summary(TotSh2.Cross.PermDiff)
TotSh2.Cross.ScanAC <- scanone(NorSpMa, pheno.col="TotSh2", model="normal",
  method="hk", addcovar=Cross)
summary(TotSh2.Cross.ScanAC, perm=TotSh2.Cross.PermAC, df=TRUE)
TotSh2.Cross.ScanIC <- scanone(NorSpMa, pheno.col="TotSh2", model="normal",
  method="hk", addcovar=Cross, intcovar=Cross)
summary(TotSh2.Cross.ScanIC, perm=TotSh2.Cross.PermIC, df=TRUE)

#NUMBER OF INFLORESCENCE SHOOTS - 3RD YEAR

seednum <- 541876145
set.seed(seednum)
TotSh3.Cross.PermAC <- scanone(NorSpMa, pheno.col="TotSh3",
  model="normal", method="hk", addcovar=Cross, n.perm=1000)
ACthresh <- summary(TotSh3.Cross.PermAC, alpha=c(0.05,0.10))
set.seed(seednum)
TotSh3.Cross.PermIC <- scanone(NorSpMa, pheno.col="TotSh3",
  model="normal", method="hk", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(TotSh3.Cross.PermIC, alpha=c(0.05,0.10))
TotSh3.Cross.PermDiff <- TotSh3.Cross.PermIC - TotSh3.Cross.PermAC
summary(TotSh3.Cross.PermDiff)
TotSh3.Cross.ScanAC <- scanone(NorSpMa, pheno.col="TotSh3", model="normal",
  method="hk", addcovar=Cross)
summary(TotSh3.Cross.ScanAC, perm=TotSh3.Cross.PermAC, df=TRUE)
TotSh3.Cross.ScanIC <- scanone(NorSpMa, pheno.col="TotSh3", model="normal",
  method="hk", addcovar=Cross, intcovar=Cross)
summary(TotSh3.Cross.ScanIC, perm=TotSh3.Cross.PermIC, df=TRUE)

#(AVERAGE) NUMBER OF FRUITS/INFLORESCENCE SHOOT - 1ST YEAR

seednum <- 576545346
set.seed(seednum)
FrSh1.Cross.PermAC <- scanone(NorSpMa, pheno.col="FrSh1",
  model="normal", method="hk", addcovar=Cross, n.perm=1000)
ACthresh <- summary(FrSh1.Cross.PermAC, alpha=c(0.05,0.10))
set.seed(seednum)
FrSh1.Cross.PermIC <- scanone(NorSpMa, pheno.col="FrSh1",
  model="normal", method="hk", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(FrSh1.Cross.PermIC, alpha=c(0.05,0.10))
FrSh1.Cross.PermDiff <- FrSh1.Cross.PermIC - FrSh1.Cross.PermAC
summary(FrSh1.Cross.PermDiff)
FrSh1.Cross.ScanAC <- scanone(NorSpMa, pheno.col="FrSh1", model="normal",
  method="hk", addcovar=Cross)
summary(FrSh1.Cross.ScanAC, perm=FrSh1.Cross.PermAC, df=TRUE)
FrSh1.Cross.ScanIC <- scanone(NorSpMa, pheno.col="FrSh1", model="normal",
  method="hk", addcovar=Cross, intcovar=Cross)
summary(FrSh1.Cross.ScanIC, perm=FrSh1.Cross.PermIC, df=TRUE)

#(AVERAGE) NUMBER OF FRUITS/INFLORESCENCE SHOOT - 2ND YEAR

seednum <- 685154874
set.seed(seednum)
FrSh2.Cross.PermAC <- scanone(NorSpMa, pheno.col="FrSh2",
  model="normal", method="hk", addcovar=Cross, n.perm=1000)
ACthresh <- summary(FrSh2.Cross.PermAC, alpha=c(0.05,0.10))
set.seed(seednum)
FrSh2.Cross.PermIC <- scanone(NorSpMa, pheno.col="FrSh2",
  model="normal", method="hk", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(FrSh2.Cross.PermIC, alpha=c(0.05,0.10))
FrSh2.Cross.PermDiff <- FrSh2.Cross.PermIC - FrSh2.Cross.PermAC
summary(FrSh2.Cross.PermDiff)
FrSh2.Cross.ScanAC <- scanone(NorSpMa, pheno.col="FrSh2", model="normal",
  method="hk", addcovar=Cross)
summary(FrSh2.Cross.ScanAC, perm=FrSh2.Cross.PermAC, df=TRUE)
FrSh2.Cross.ScanIC <- scanone(NorSpMa, pheno.col="FrSh2", model="normal",
  method="hk", addcovar=Cross, intcovar=Cross)
summary(FrSh2.Cross.ScanIC, perm=FrSh2.Cross.PermIC, df=TRUE)

#(AVERAGE) NUMBER OF FRUITS/INFLORESCENCE SHOOT - 3RD YEAR

seednum <- 864354552
set.seed(seednum)
FrSh3.Cross.PermAC <- scanone(NorSpMa, pheno.col="FrSh3",
  model="normal", method="hk", addcovar=Cross, n.perm=1000)
ACthresh <- summary(FrSh3.Cross.PermAC, alpha=c(0.05,0.10))
set.seed(seednum)
FrSh3.Cross.PermIC <- scanone(NorSpMa, pheno.col="FrSh3",
  model="normal", method="hk", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(FrSh3.Cross.PermIC, alpha=c(0.05,0.10))
FrSh3.Cross.PermDiff <- FrSh3.Cross.PermIC - FrSh3.Cross.PermAC
summary(FrSh3.Cross.PermDiff)
FrSh3.Cross.ScanAC <- scanone(NorSpMa, pheno.col="FrSh3", model="normal",
  method="hk", addcovar=Cross)
summary(FrSh3.Cross.ScanAC, perm=FrSh3.Cross.PermAC, df=TRUE)
FrSh3.Cross.ScanIC <- scanone(NorSpMa, pheno.col="FrSh3", model="normal",
  method="hk", addcovar=Cross, intcovar=Cross)
summary(FrSh3.Cross.ScanIC, perm=FrSh3.Cross.PermIC, df=TRUE)

# NUMBER OF FRUITS/PLANT - 4TH YEAR

seednum <- 554448412
set.seed(seednum)
TotFr4.Cross.PermAC <- scanone(NorSpMa, pheno.col="TotFr4",
  model="normal", method="hk", addcovar=Cross, n.perm=1000)
ACthresh <- summary(TotFr4.Cross.PermAC, alpha=c(0.05,0.10))
set.seed(seednum)
TotFr4.Cross.PermIC <- scanone(NorSpMa, pheno.col="TotFr4",
  model="normal", method="hk", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(TotFr4.Cross.PermIC, alpha=c(0.05,0.10))
TotFr4.Cross.PermDiff <- TotFr4.Cross.PermIC - TotFr4.Cross.PermAC
summary(TotFr4.Cross.PermDiff)
TotFr4.Cross.ScanAC <- scanone(NorSpMa, pheno.col="TotFr4", model="normal",
  method="hk", addcovar=Cross)
summary(TotFr4.Cross.ScanAC, perm=TotFr4.Cross.PermAC, df=TRUE)
TotFr4.Cross.ScanIC <- scanone(NorSpMa, pheno.col="TotFr4", model="normal",
  method="hk", addcovar=Cross, intcovar=Cross)
summary(TotFr4.Cross.ScanIC, perm=TotFr4.Cross.PermIC, df=TRUE)

# NUMBER OF FRUITS/PLANT - 5TH YEAR

seednum <- 123484456
set.seed(seednum)
TotFr5.Cross.PermAC <- scanone(NorSpMa, pheno.col="TotFr5",
  model="normal", method="hk", addcovar=Cross, n.perm=1000)
ACthresh <- summary(TotFr5.Cross.PermAC, alpha=c(0.05,0.10))
set.seed(seednum)
TotFr5.Cross.PermIC <- scanone(NorSpMa, pheno.col="TotFr5",
  model="normal", method="hk", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(TotFr5.Cross.PermIC, alpha=c(0.05,0.10))
TotFr5.Cross.PermDiff <- TotFr5.Cross.PermIC - TotFr5.Cross.PermAC
summary(TotFr5.Cross.PermDiff)
TotFr5.Cross.ScanAC <- scanone(NorSpMa, pheno.col="TotFr5", model="normal",
  method="hk", addcovar=Cross)
summary(TotFr5.Cross.ScanAC, perm=TotFr5.Cross.PermAC, df=TRUE)
TotFr5.Cross.ScanIC <- scanone(NorSpMa, pheno.col="TotFr5", model="normal",
  method="hk", addcovar=Cross, intcovar=Cross)
summary(TotFr5.Cross.ScanIC, perm=TotFr5.Cross.PermIC, df=TRUE)

# (AVERAGE) NUMBER OF SEEDS / FRUIT - 1ST YEAR

seednum <- 576545346
set.seed(seednum)
SeFrG1.Cross.PermAC <- scanone(NorSpMa, pheno.col="SeFrG1",
  model="normal", method="hk", addcovar=Cross, n.perm=1000)
ACthresh <- summary(SeFrG1.Cross.PermAC, alpha=c(0.05,0.10))
set.seed(seednum)
SeFrG1.Cross.PermIC <- scanone(NorSpMa, pheno.col="SeFrG1",
  model="normal", method="hk", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(SeFrG1.Cross.PermIC, alpha=c(0.05,0.10))
SeFrG1.Cross.PermDiff <- SeFrG1.Cross.PermIC - SeFrG1.Cross.PermAC
summary(SeFrG1.Cross.PermDiff)
SeFrG1.Cross.ScanAC <- scanone(NorSpMa, pheno.col="SeFrG1", model="normal",
  method="hk", addcovar=Cross)
summary(SeFrG1.Cross.ScanAC, perm=SeFrG1.Cross.PermAC, df=TRUE)
SeFrG1.Cross.ScanIC <- scanone(NorSpMa, pheno.col="SeFrG1", model="normal",
  method="hk", addcovar=Cross, intcovar=Cross)
summary(SeFrG1.Cross.ScanIC, perm=SeFrG1.Cross.PermIC, df=TRUE)

# (AVERAGE) NUMBER OF SEEDS / FRUIT - 2ND YEAR

seednum <- 984514342
set.seed(seednum)
SeFrG2.Cross.PermAC <- scanone(NorSpMa, pheno.col="SeFrG2",
  model="normal", method="hk", addcovar=Cross, n.perm=1000)
ACthresh <- summary(SeFrG2.Cross.PermAC, alpha=c(0.05,0.10))
set.seed(seednum)
SeFrG2.Cross.PermIC <- scanone(NorSpMa, pheno.col="SeFrG2",
  model="normal", method="hk", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(SeFrG2.Cross.PermIC, alpha=c(0.05,0.10))
SeFrG2.Cross.PermDiff <- SeFrG2.Cross.PermIC - SeFrG2.Cross.PermAC
summary(SeFrG2.Cross.PermDiff)
SeFrG2.Cross.ScanAC <- scanone(NorSpMa, pheno.col="SeFrG2", model="normal",
  method="hk", addcovar=Cross)
summary(SeFrG2.Cross.ScanAC, perm=SeFrG2.Cross.PermAC, df=TRUE)
SeFrG2.Cross.ScanIC <- scanone(NorSpMa, pheno.col="SeFrG2", model="normal",
  method="hk", addcovar=Cross, intcovar=Cross)
summary(SeFrG2.Cross.ScanIC, perm=SeFrG2.Cross.PermIC, df=TRUE)

# (AVERAGE) NUMBER OF SEEDS / FRUIT - 3RD YEAR

seednum <- 432773520
set.seed(seednum)
SeFrG3.Cross.PermAC <- scanone(NorSpMa, pheno.col="SeFrG3",
  model="normal", method="hk", addcovar=Cross, n.perm=1000)
ACthresh <- summary(SeFrG3.Cross.PermAC, alpha=c(0.05,0.10))
set.seed(seednum)
SeFrG3.Cross.PermIC <- scanone(NorSpMa, pheno.col="SeFrG3",
  model="normal", method="hk", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(SeFrG3.Cross.PermIC, alpha=c(0.05,0.10))
SeFrG3.Cross.PermDiff <- SeFrG3.Cross.PermIC - SeFrG3.Cross.PermAC
summary(SeFrG3.Cross.PermDiff)
SeFrG3.Cross.ScanAC <- scanone(NorSpMa, pheno.col="SeFrG3", model="normal",
  method="hk", addcovar=Cross)
summary(SeFrG3.Cross.ScanAC, perm=SeFrG3.Cross.PermAC, df=TRUE)
SeFrG3.Cross.ScanIC <- scanone(NorSpMa, pheno.col="SeFrG3", model="normal",
  method="hk", addcovar=Cross, intcovar=Cross)
summary(SeFrG3.Cross.ScanIC, perm=SeFrG3.Cross.PermIC, df=TRUE)

# FLOWERING START DATE - 1ST YEAR

seednum <- 576545496
set.seed(seednum)
FlStart1.Cross.PermAC <- scanone(NorSpMa, pheno.col="FlStart1",
  model="normal", method="hk", addcovar=Cross, n.perm=1000)
ACthresh <- summary(FlStart1.Cross.PermAC, alpha=c(0.05,0.10))
set.seed(seednum)
FlStart1.Cross.PermIC <- scanone(NorSpMa, pheno.col="FlStart1",
  model="normal", method="hk", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(FlStart1.Cross.PermIC, alpha=c(0.05,0.10))
FlStart1.Cross.PermDiff <- FlStart1.Cross.PermIC - FlStart1.Cross.PermAC
summary(FlStart1.Cross.PermDiff)
FlStart1.Cross.ScanAC <- scanone(NorSpMa, pheno.col="FlStart1", model="normal",
  method="hk", addcovar=Cross)
summary(FlStart1.Cross.ScanAC, perm=FlStart1.Cross.PermAC, df=TRUE)
FlStart1.Cross.ScanIC <- scanone(NorSpMa, pheno.col="FlStart1", model="normal",
  method="hk", addcovar=Cross, intcovar=Cross)
summary(FlStart1.Cross.ScanIC, perm=FlStart1.Cross.PermIC, df=TRUE)

# FLOWERING START DATE - 2ND YEAR

seednum <- 984447342
set.seed(seednum)
FlStart2.Cross.PermAC <- scanone(NorSpMa, pheno.col="FlStart2",
  model="normal", method="hk", addcovar=Cross, n.perm=1000)
ACthresh <- summary(FlStart2.Cross.PermAC, alpha=c(0.05,0.10))
set.seed(seednum)
FlStart2.Cross.PermIC <- scanone(NorSpMa, pheno.col="FlStart2",
  model="normal", method="hk", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(FlStart2.Cross.PermIC, alpha=c(0.05,0.10))
FlStart2.Cross.PermDiff <- FlStart2.Cross.PermIC - FlStart2.Cross.PermAC
summary(FlStart2.Cross.PermDiff)
FlStart2.Cross.ScanAC <- scanone(NorSpMa, pheno.col="FlStart2", model="normal",
  method="hk", addcovar=Cross)
summary(FlStart2.Cross.ScanAC, perm=FlStart2.Cross.PermAC, df=TRUE)
FlStart2.Cross.ScanIC <- scanone(NorSpMa, pheno.col="FlStart2", model="normal",
  method="hk", addcovar=Cross, intcovar=Cross)
summary(FlStart2.Cross.ScanIC, perm=FlStart2.Cross.PermIC, df=TRUE)

# FLOWERING START DATE - 3RD YEAR

seednum <- 447873520
set.seed(seednum)
FlStart3.Cross.PermAC <- scanone(NorSpMa, pheno.col="FlStart3",
  model="normal", method="hk", addcovar=Cross, n.perm=1000)
ACthresh <- summary(FlStart3.Cross.PermAC, alpha=c(0.05,0.10))
set.seed(seednum)
FlStart3.Cross.PermIC <- scanone(NorSpMa, pheno.col="FlStart3",
  model="normal", method="hk", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(FlStart3.Cross.PermIC, alpha=c(0.05,0.10))
FlStart3.Cross.PermDiff <- FlStart3.Cross.PermIC - FlStart3.Cross.PermAC
summary(FlStart3.Cross.PermDiff)
FlStart3.Cross.ScanAC <- scanone(NorSpMa, pheno.col="FlStart3", model="normal",
  method="hk", addcovar=Cross)
summary(FlStart3.Cross.ScanAC, perm=FlStart3.Cross.PermAC, df=TRUE)
FlStart3.Cross.ScanIC <- scanone(NorSpMa, pheno.col="FlStart3", model="normal",
  method="hk", addcovar=Cross, intcovar=Cross)
summary(FlStart3.Cross.ScanIC, perm=FlStart3.Cross.PermIC, df=TRUE)

#NONPARAMETRIC GENOME-WIDE ANALYSIS OF FLOWERING START DATE

FlStart1.Scan.NP<- scanone(NorSpMa, pheno.col="FlStart1", model="np", ties.random=FALSE )
FlStart1.Perm.NP<- scanone(NorSpMa, pheno.col="FlStart1", model="np",  n.perm=1000)

FlStart2.Scan.NP<- scanone(NorSpMa, pheno.col="FlStart2", model="np", ties.random=FALSE )
FlStart2.Perm.NP<- scanone(NorSpMa, pheno.col="FlStart2", model="np",  n.perm=1000)

FlStart3.Scan.NP<- scanone(NorSpMa, pheno.col="FlStart3", model="np", ties.random=FALSE )
FlStart3.Perm.NP<- scanone(NorSpMa, pheno.col="FlStart3", model="np",  n.perm=1000)

summary (FlStart1.Scan.NP)
summary(FlStart1.Perm.NP)

summary (FlStart2.Scan.NP)
summary(FlStart2.Perm.NP)

summary (FlStart3.Scan.NP)
summary(FlStart3.Perm.NP)



#GENERATING SUMMARIES OF QTL-EFFECTS
SurvWin2.LOD.AC <- summary(SurvWin2.Cross.ScanAC, perms=SurvWin2.Cross.PermAC,alpha=0.05)
SurvWin3.LOD.AC <- summary(SurvWin3.Cross.ScanAC, perms=SurvWin3.Cross.PermAC,alpha=0.05)
SurvWin4.LOD.AC <- summary(SurvWin4.Cross.ScanAC, perms=SurvWin4.Cross.PermAC,alpha=0.05)
SurvWin5.LOD.AC <- summary(SurvWin5.Cross.ScanAC, perms=SurvWin5.Cross.PermAC,alpha=0.05)
Flow2.LOD.AC <- summary(Flow2.Cross.ScanAC, perms=Flow2.Cross.PermAC,alpha=0.05)
Flow3.LOD.AC <- summary(Flow3.Cross.ScanAC, perms=Flow3.Cross.PermAC,alpha=0.05)
Flow4.LOD.AC <- summary(Flow4.Cross.ScanAC, perms=Flow4.Cross.PermAC,alpha=0.05)
Flow5.LOD.AC <- summary(Flow5.Cross.ScanAC, perms=Flow5.Cross.PermAC,alpha=0.05)
TotSh1.LOD.AC <- summary(TotSh1.Cross.ScanAC, perms=TotSh1.Cross.PermAC,alpha=0.05)
TotSh2.LOD.AC <- summary(TotSh2.Cross.ScanAC, perms=TotSh2.Cross.PermAC,alpha=0.05)
TotSh3.LOD.AC <- summary(TotSh3.Cross.ScanAC, perms=TotSh3.Cross.PermAC,alpha=0.05)
FrSh1.LOD.AC <- summary(FrSh1.Cross.ScanAC, perms=FrSh1.Cross.PermAC,alpha=0.05)
FrSh2.LOD.AC <- summary(FrSh2.Cross.ScanAC, perms=FrSh2.Cross.PermAC,alpha=0.05)
FrSh3.LOD.AC <- summary(FrSh3.Cross.ScanAC, perms=FrSh3.Cross.PermAC,alpha=0.05)
TotFr4.LOD.AC <- summary(TotFr4.Cross.ScanAC, perms=TotFr4.Cross.PermAC,alpha=0.05)
TotFr5.LOD.AC <- summary(TotFr5.Cross.ScanAC, perms=TotFr5.Cross.PermAC,alpha=0.05)
SeFrG1.LOD.AC <- summary(SeFrG1.Cross.ScanAC, perms=SeFrG1.Cross.PermAC,alpha=0.05)
SeFrG2.LOD.AC <- summary(SeFrG2.Cross.ScanAC, perms=SeFrG2.Cross.PermAC,alpha=0.05)
SeFrG3.LOD.AC <- summary(SeFrG3.Cross.ScanAC, perms=SeFrG3.Cross.PermAC,alpha=0.05)
FlStart1.LOD.AC <- summary(FlStart1.Cross.ScanAC, perms=FlStart1.Cross.PermAC,alpha=0.05)
FlStart2.LOD.AC <- summary(FlStart2.Cross.ScanAC, perms=FlStart2.Cross.PermAC,alpha=0.05)
FlStart3.LOD.AC <- summary(FlStart3.Cross.ScanAC, perms=FlStart3.Cross.PermAC,alpha=0.05)
FlStart1.LOD.NP <- summary(FlStart1.Scan.NP, perms=FlStart1.Perm.NP, alpha=0.05)
FlStart2.LOD.NP <- summary(FlStart2.Scan.NP, perms=FlStart2.Perm.NP, alpha=0.05)
FlStart3.LOD.NP <- summary(FlStart3.Scan.NP, perms=FlStart3.Perm.NP, alpha=0.05)

#GENERATING SUMMARIES OF QTL WITH CYTOPLASMIC INTERACTIONS
SurvWin2.LOD.IC <- summary(SurvWin2.Cross.ScanIC-SurvWin2.Cross.ScanAC, perms=SurvWin2.Cross.PermDiff,alpha=0.05)
SurvWin3.LOD.IC <- summary(SurvWin3.Cross.ScanIC-SurvWin3.Cross.ScanAC, perms=SurvWin3.Cross.PermDiff,alpha=0.05)
SurvWin4.LOD.IC <- summary(SurvWin4.Cross.ScanIC-SurvWin4.Cross.ScanAC, perms=SurvWin4.Cross.PermDiff,alpha=0.05)
SurvWin5.LOD.IC <- summary(SurvWin5.Cross.ScanIC-SurvWin5.Cross.ScanAC, perms=SurvWin5.Cross.PermDiff,alpha=0.05)
Flow2.LOD.IC <- summary(Flow2.Cross.ScanIC-Flow2.Cross.ScanAC, perms=Flow2.Cross.PermDiff,alpha=0.05)
Flow3.LOD.IC <- summary(Flow3.Cross.ScanIC-Flow3.Cross.ScanAC, perms=Flow3.Cross.PermDiff,alpha=0.05)
Flow4.LOD.IC <- summary(Flow4.Cross.ScanIC-Flow4.Cross.ScanAC, perms=Flow4.Cross.PermDiff,alpha=0.05)
Flow5.LOD.IC <- summary(Flow5.Cross.ScanIC-Flow5.Cross.ScanAC, perms=Flow5.Cross.PermDiff,alpha=0.05)
TotSh1.LOD.IC <- summary(TotSh1.Cross.ScanIC-TotSh1.Cross.ScanAC, perms=TotSh1.Cross.PermDiff,alpha=0.05)
TotSh2.LOD.IC <- summary(TotSh2.Cross.ScanIC-TotSh2.Cross.ScanAC, perms=TotSh2.Cross.PermDiff,alpha=0.05)
TotSh3.LOD.IC <- summary(TotSh3.Cross.ScanIC-TotSh3.Cross.ScanAC, perms=TotSh3.Cross.PermDiff,alpha=0.05)
FrSh1.LOD.IC <- summary(FrSh1.Cross.ScanIC-FrSh1.Cross.ScanAC, perms=FrSh1.Cross.PermDiff,alpha=0.05)
FrSh2.LOD.IC <- summary(FrSh2.Cross.ScanIC-FrSh2.Cross.ScanAC, perms=FrSh2.Cross.PermDiff,alpha=0.05)
FrSh3.LOD.IC <- summary(FrSh3.Cross.ScanIC-FrSh3.Cross.ScanAC, perms=FrSh3.Cross.PermDiff,alpha=0.05)
TotFr4.LOD.IC <- summary(TotFr4.Cross.ScanIC-TotFr4.Cross.ScanAC, perms=TotFr4.Cross.PermDiff,alpha=0.05)
TotFr5.LOD.IC <- summary(TotFr5.Cross.ScanIC-TotFr5.Cross.ScanAC, perms=TotFr5.Cross.PermDiff,alpha=0.05)
SeFrG1.LOD.IC <- summary(SeFrG1.Cross.ScanIC-SeFrG1.Cross.ScanAC, perms=SeFrG1.Cross.PermDiff,alpha=0.05)
SeFrG2.LOD.IC <- summary(SeFrG2.Cross.ScanIC-SeFrG2.Cross.ScanAC, perms=SeFrG2.Cross.PermDiff,alpha=0.05)
SeFrG3.LOD.IC <- summary(SeFrG3.Cross.ScanIC-SeFrG3.Cross.ScanAC, perms=SeFrG3.Cross.PermDiff,alpha=0.05)
FlStart1.LOD.IC <- summary(FlStart1.Cross.ScanIC-FlStart1.Cross.ScanAC, perms=FlStart1.Cross.PermDiff,alpha=0.05)
FlStart2.LOD.IC <- summary(FlStart2.Cross.ScanIC-FlStart2.Cross.ScanAC, perms=FlStart2.Cross.PermDiff,alpha=0.05)
FlStart3.LOD.IC <- summary(FlStart3.Cross.ScanIC-FlStart3.Cross.ScanAC, perms=FlStart3.Cross.PermDiff,alpha=0.05)

#GENOME-WIDE SIGNIFICANT QTL PEAKS

#QTL WITH MAIN EFFECTS

SurvWin2.LOD.AC
SurvWin3.LOD.AC
SurvWin4.LOD.AC
SurvWin5.LOD.AC
Flow2.LOD.AC
Flow3.LOD.AC
Flow4.LOD.AC
Flow5.LOD.AC
TotSh1.LOD.AC
TotSh2.LOD.AC
TotSh3.LOD.AC
FrSh1.LOD.AC
FrSh2.LOD.AC
FrSh3.LOD.AC
TotFr4.LOD.AC
TotFr5.LOD.AC
SeFrG1.LOD.AC
SeFrG2.LOD.AC
SeFrG3.LOD.AC
FlStart1.LOD.AC
FlStart2.LOD.AC
FlStart3.LOD.AC
FlStart1.LOD.NP
FlStart2.LOD.NP
FlStart3.LOD.NP

#QTL x CYTOPLASM-INTERACTION

SurvWin2.LOD.IC
SurvWin3.LOD.IC
SurvWin4.LOD.IC
SurvWin5.LOD.IC
Flow2.LOD.IC
Flow3.LOD.IC
Flow4.LOD.IC
Flow5.LOD.IC
TotSh1.LOD.IC
TotSh2.LOD.IC
TotSh3.LOD.IC
FrSh1.LOD.IC
FrSh2.LOD.IC
FrSh3.LOD.IC
TotFr4.LOD.IC
TotFr5.LOD.IC
SeFrG1.LOD.IC
SeFrG2.LOD.IC
SeFrG3.LOD.IC
FlStart1.LOD.IC
FlStart2.LOD.IC
FlStart3.LOD.IC


#TESTING FOR SIGNIFICANCE AND SIZE OF ADDITIVE AND DOMINANCE EFFECTS AT GENOME-WIDE SIGNIFICANT PEAKS
#(ESTIMATED ALSO SEPARATELY FOR PLANTS WITH DIFFERENT CYTOPLASMIC BACKGROUNDS IN CASES OF QTL X CYTOPL. INTERACTIONS)

#CUSTOM SCRIPT FOR ESTIMATING ADDITIVE AND DOMINANCE EFFECTS

adimodel <- function(cross,chr,pos,trait,covariate,additive=FALSE,
  family="gaussian") {
traitval <- trait
if(is.character(trait)) {traitval <- pull.pheno(cross,trait)}
covval <- covariate
if(is.character(covariate)) {covval <- pull.pheno(cross,covariate)}
geno <- data.frame(cross$geno[[chr]]$prob[,pos,])
geno$a <- geno$AC - geno$BD
geno$d <- (geno$BC + geno$AD - geno$AC - geno$BD)/2
geno$i <- geno$BC - geno$AD

testmod <- glm(traitval ~ a + d + i, data=geno, family=family)
s.testmod <- summary(testmod)

testmod2 <- glm(traitval  ~ a + d + i + covval,
  data=geno, family=family)
s.testmod2 <- summary(testmod2)

testmod3 <- glm(traitval  ~ (a + d + i) * covval,
  data=geno, family=family)
s.testmod3 <- summary(testmod3)
if(family=="gaussian") {
 a.testmod <- anova(testmod,testmod2,testmod3, test="F")
 }
 else {
 a.testmod <- anova(testmod,testmod2,testmod3, test="Chisq")
}
# If additive=TRUE, only output is additive coeff and SE for testmod2.
# If additive=FALSE, generate full summaries of a,d,i model output
#  for all three models plus anova.
if(additive==TRUE){
 output <- s.testmod2$coefficients[2,c(1,2)]
 }
 else {
output <- list(s.testmod, s.testmod2, s.testmod3, a.testmod)
 }
return(output)
}

Cross <- pull.pheno(NorSpMa, "Cytop")

#LG1
adimodel(NorSpMa, chr=1, pos="loc24", trait="SurvWin2",covariate="Cytop", additive=F,family="binomial")
adimodel(NorSpMa, chr=1, pos="loc26", trait="SurvWin3",covariate="Cytop", additive=F,family="binomial")
adimodel(NorSpMa, chr=1, pos="loc26", trait="SurvWin4",covariate="Cytop", additive=F,family="binomial")
adimodel(NorSpMa, chr=1, pos="loc26", trait="SeFrG1",covariate="Cytop", additive=F)
adimodel(NorSpMa, chr=1, pos="loc36", trait="FrSh2",covariate="Cytop", additive=F)
adimodel(NorSpMa, chr=1, pos="loc50", trait="Flow4",covariate="Cytop", additive=F,family="binomial")
adimodel(subset(NorSpMa,ind=Cross==0), chr=1, pos="loc50", trait="Flow4",covariate="Unif", additive=F,family="binomial")
adimodel(subset(NorSpMa,ind=Cross==1), chr=1, pos="loc50", trait="Flow4",covariate="Unif", additive=F,family="binomial")
adimodel(NorSpMa, chr=1, pos="loc78", trait="TotSh1",covariate="Cytop", additive=F)
adimodel(NorSpMa, chr=1, pos="loc20", trait="FlStart1",covariate="Cytop", additive=F)
adimodel(NorSpMa, chr=1, pos="loc36", trait="FlStart2",covariate="Cytop", additive=F)

#LG2
adimodel(NorSpMa, chr=2, pos="loc46", trait="FrSh1",covariate="Cytop", additive=F)
adimodel(NorSpMa, chr=2, pos="loc54", trait="SurvWin5",covariate="Cytop", additive=F,family="binomial")

#LG3
adimodel(NorSpMa, chr=3, pos="loc6", trait="SurvWin5",covariate="Cytop", additive=F,family="binomial")
adimodel(subset(NorSpMa,ind=Cross==0), chr=3, pos="loc6", trait="SurvWin5",covariate="Unif", additive=F,family="binomial")
adimodel(subset(NorSpMa,ind=Cross==1), chr=3, pos="loc6", trait="SurvWin5",covariate="Unif", additive=F,family="binomial")
adimodel(NorSpMa, chr=3, pos="loc8", trait="SurvWin4",covariate="Cytop", additive=F,family="binomial")
adimodel(subset(NorSpMa,ind=Cross==0), chr=3, pos="loc8", trait="SurvWin4",covariate="Unif", additive=F,family="binomial")
adimodel(subset(NorSpMa,ind=Cross==1), chr=3, pos="loc8", trait="SurvWin4",covariate="Unif", additive=F,family="binomial")
adimodel(NorSpMa, chr=3, pos="loc8", trait="FlStart3",covariate="Cytop", additive=F)
adimodel(NorSpMa, chr=3, pos="loc14", trait="SurvWin3",covariate="Cytop", additive=F,family="binomial")
adimodel(subset(NorSpMa,ind=Cross==0), chr=3, pos="loc14", trait="SurvWin3",covariate="Unif", additive=F,family="binomial")
adimodel(subset(NorSpMa,ind=Cross==1), chr=3, pos="loc14", trait="SurvWin3",covariate="Unif", additive=F,family="binomial")
adimodel(NorSpMa, chr=3, pos="loc16", trait="SurvWin2",covariate="Cytop", additive=F,family="binomial")
adimodel(subset(NorSpMa,ind=Cross==0), chr=3, pos="loc16", trait="SurvWin2",covariate="Unif", additive=F,family="binomial")
adimodel(subset(NorSpMa,ind=Cross==1), chr=3, pos="loc16", trait="SurvWin2",covariate="Unif", additive=F,family="binomial")
adimodel(NorSpMa, chr=3, pos="loc26", trait="FlStart1",covariate="Cytop", additive=F)

#LG4
adimodel(NorSpMa, chr=4, pos="CK2alpha2", trait="Flow4",covariate="Cytop", additive=F,family="binomial")
adimodel(NorSpMa, chr=4, pos="loc8", trait="SurvWin5",covariate="Cytop", additive=F,family="binomial")
adimodel(NorSpMa, chr=4, pos="loc12", trait="SeFrG1",covariate="Cytop", additive=F)
adimodel(subset(NorSpMa,ind=Cross==0), chr=4, pos="loc12", trait="SeFrG1",covariate="Unif", additive=F)
adimodel(subset(NorSpMa,ind=Cross==1), chr=4, pos="loc12", trait="SeFrG1",covariate="Unif", additive=F)
adimodel(NorSpMa, chr=4, pos="loc22", trait="TotFr5",covariate="Cytop", additive=F)
adimodel(subset(NorSpMa,ind=Cross==0), chr=4, pos="loc22", trait="TotFr5",covariate="Unif", additive=F)
adimodel(subset(NorSpMa,ind=Cross==1), chr=4, pos="loc22", trait="TotFr5",covariate="Unif", additive=F)
adimodel(NorSpMa, chr=4, pos="loc30", trait="SurvWin4",covariate="Cytop", additive=F,family="binomial")
adimodel(NorSpMa, chr=4, pos="loc36", trait="FlStart1",covariate="Cytop", additive=F)
adimodel(NorSpMa, chr=4, pos="loc54", trait="FlStart2",covariate="Cytop", additive=F)

#LG5
adimodel(NorSpMa, chr=5, pos="loc42", trait="FrSh2",covariate="Cytop", additive=F)
adimodel(subset(NorSpMa,ind=Cross==0), chr=5, pos="loc42", trait="FrSh2",covariate="Cytop", additive=F)
adimodel(subset(NorSpMa,ind=Cross==1), chr=5, pos="loc42", trait="FrSh2",covariate="Cytop", additive=F)

#LG6
adimodel(NorSpMa, chr=6, pos="loc10", trait="SurvWin3",covariate="Cytop", additive=F,family="binomial")

#LG7
adimodel(NorSpMa, chr=7, pos="loc20", trait="SeFrG1",covariate="Cytop", additive=F)
adimodel(NorSpMa, chr=7, pos="loc24", trait="SurvWin5",covariate="Cytop", additive=F,family="binomial")
adimodel(NorSpMa, chr=7, pos="loc42", trait="FrSh2",covariate="Cytop", additive=F)
adimodel(subset(NorSpMa,ind=Cross==0), chr=7, pos="loc42", trait="FrSh2",covariate="Unif", additive=F)
adimodel(subset(NorSpMa,ind=Cross==1), chr=7, pos="loc42", trait="FrSh2",covariate="Unif", additive=F)

#LG8
adimodel(NorSpMa, chr=8, pos="loc22", trait="SurvWin2",covariate="Cytop", additive=F,family="binomial")
adimodel(NorSpMa, chr=8, pos="loc36", trait="FrSh2",covariate="Cytop", additive=F)
adimodel(NorSpMa, chr=8, pos="loc38", trait="SurvWin4",covariate="Cytop", additive=F,family="binomial")
adimodel(NorSpMa, chr=8, pos="FRO1", trait="SurvWin3",covariate="Cytop", additive=F,family="binomial")
adimodel(NorSpMa, chr=8, pos="FRO1", trait="SurvWin5",covariate="Cytop", additive=F,family="binomial")
adimodel(NorSpMa, chr=8, pos="FRO1", trait="SeFrG2",covariate="Cytop", additive=F)
adimodel(NorSpMa, chr=8, pos="loc20", trait="FlStart2",covariate="Cytop", additive=F)


###SINGLE-MARKER TESTS FOR PUTATIVE QTL EFFECTS

##ADDITIVE QTL (TESTED IF ADDITIVE QTL WAS FOUND IN ANOTHER ENVIRONMENT OR FOR RELATED TRAIT

#TESTING FOR SIGNIFICANCE OF QTL MAIN EFFECT AND ADDITIVE EFFECT

#LG1

LG1_SurvWin5_M_loc38 <- makeqtl(NorSpMa,1, 38, what="prob")
summary(LG1_SurvWin5_M_loc38)
LG1_SurvWin5_M_loc38_qtl <- fitqtl(NorSpMa, LG1_SurvWin5_M_loc38, pheno.col="SurvWin5", formula=y~Q1, method="hk", get.ests=TRUE)
summary(LG1_SurvWin5_M_loc38_qtl)
adimodel(NorSpMa, chr=1, pos="loc38", trait="SurvWin5",covariate="Cytop", additive=F,family="binomial")

LG1_FrSh1_M_loc26 <- makeqtl(NorSpMa,1, 26, what="prob")
summary(LG1_FrSh1_M_loc26)
LG1_FrSh1_M_loc26_qtl <- fitqtl(NorSpMa, LG1_FrSh1_M_loc26, pheno.col="FrSh1", formula=y~Q1, method="hk", get.ests=TRUE)
summary(LG1_FrSh1_M_loc26_qtl)
adimodel(NorSpMa, chr=1, pos="loc26", trait="FrSh1",covariate="Cytop", additive=F)

LG1_FrSh3_M_loc34 <- makeqtl(NorSpMa,1, 34, what="prob")
summary(LG1_FrSh3_M_loc34)
LG1_FrSh3_M_loc34_qtl <- fitqtl(NorSpMa, LG1_FrSh3_M_loc34, pheno.col="FrSh3", formula=y~Q1, method="hk", get.ests=TRUE)
summary(LG1_FrSh3_M_loc34_qtl)
adimodel(NorSpMa, chr=1, pos="loc34", trait="FrSh3",covariate="Cytop", additive=F)

LG1_SeFrG2_M_loc38 <- makeqtl(NorSpMa,1, 38, what="prob")
summary(LG1_SeFrG2_M_loc38)
LG1_SeFrG2_M_loc38_qtl <- fitqtl(NorSpMa, LG1_SeFrG2_M_loc38, pheno.col="SeFrG2", formula=y~Q1, method="hk", get.ests=TRUE)
summary(LG1_SeFrG2_M_loc38_qtl)
adimodel(NorSpMa, chr=1, pos="loc38", trait="SeFrG2",covariate="Cytop", additive=F)

#LG2

LG2_SeFrG1_M_loc12 <- makeqtl(NorSpMa,2, 12, what="prob")
summary(LG2_SeFrG1_M_loc12)
LG2_SeFrG1_M_loc12_qtl <- fitqtl(NorSpMa, LG2_SeFrG1_M_loc12, pheno.col="SeFrG1", formula=y~Q1, method="hk", get.ests=TRUE)
summary(LG2_SeFrG1_M_loc12_qtl)
adimodel(NorSpMa, chr=2, pos="loc12", trait="SeFrG1",covariate="Cytop", additive=F)

LG2_TotSh2_C_loc56 <- makeqtl(NorSpMa,2, 56, what="prob")
summary(LG2_TotSh2_C_loc56)
LG2_TotSh2_C_loc56_qtl <- fitqtl(NorSpMa, LG2_TotSh2_C_loc56, pheno.col="TotSh2", formula=y~Q1, method="hk", get.ests=TRUE)
summary(LG2_TotSh2_C_loc56_qtl)
adimodel(NorSpMa, chr=2, pos="loc56", trait="TotSh2",covariate="Cytop", additive=F)
adimodel(subset(NorSpMa,ind=Cross==0), chr=2, pos="loc56", trait="TotSh2",covariate="Unif", additive=F)
adimodel(subset(NorSpMa,ind=Cross==1), chr=2, pos="loc56", trait="TotSh2",covariate="Unif", additive=F)

LG2_TotSh3_C_loc58 <- makeqtl(NorSpMa,2, 58, what="prob")
summary(LG2_TotSh3_C_loc58)
LG2_TotSh3_C_loc58_qtl <- fitqtl(NorSpMa, LG2_TotSh3_C_loc58, pheno.col="TotSh3", formula=y~Q1, method="hk", get.ests=TRUE)
summary(LG2_TotSh3_C_loc58_qtl)
adimodel(NorSpMa, chr=2, pos="AT1G74600", trait="TotSh3",covariate="Cytop", additive=F)
adimodel(subset(NorSpMa,ind=Cross==0), chr=2, pos="AT1G74600", trait="TotSh3",covariate="Unif", additive=F)
adimodel(subset(NorSpMa,ind=Cross==1), chr=2, pos="AT1G74600", trait="TotSh3",covariate="Unif", additive=F)

LG2_FrSh2_M_loc46 <- makeqtl(NorSpMa,2, 46, what="prob")
summary(LG2_FrSh2_M_loc46)
LG2_FrSh2_M_loc46_qtl <- fitqtl(NorSpMa, LG2_FrSh2_M_loc46, pheno.col="FrSh2", formula=y~Q1, method="hk", get.ests=TRUE)
summary(LG2_FrSh2_M_loc46_qtl)
adimodel(NorSpMa, chr=2, pos="loc46", trait="FrSh2",covariate="Cytop", additive=F)

LG2_TotFr5_M_loc46 <- makeqtl(NorSpMa,2, 46, what="prob")
summary(LG2_TotFr5_M_loc46)
LG2_TotFr5_M_loc46_qtl <- fitqtl(NorSpMa, LG2_TotFr5_M_loc46, pheno.col="TotFr5", formula=y~Q1, method="hk", get.ests=TRUE)
summary(LG2_TotFr5_M_loc46_qtl)
adimodel(NorSpMa, chr=2, pos="loc46", trait="TotFr5",covariate="Cytop", additive=F)

#LG3

LG3_FlStart2_M_loc22 <- makeqtl(NorSpMa,3, 22, what="prob")
summary(LG3_FlStart2_M_loc22)
LG3_FlStart2_M_loc22_qtl <- fitqtl(NorSpMa, LG3_FlStart2_M_loc22, pheno.col="FlStart2", formula=y~Q1, method="hk", get.ests=TRUE)
summary (LG3_FlStart2_M_loc22_qtl)
adimodel(NorSpMa, chr=3, pos="loc22", trait="FlStart2",covariate="Cytop", additive=F)

#LG4

LG4_SurvWin2_M_loc18 <- makeqtl(NorSpMa,4, 18, what="prob")
summary(LG4_SurvWin2_M_loc18)
LG4_SurvWin2_M_loc18_qtl <- fitqtl(NorSpMa, LG4_SurvWin2_M_loc18, pheno.col="SurvWin2", formula=y~Q1, method="hk", get.ests=TRUE)
summary (LG4_SurvWin2_M_loc18_qtl)
adimodel(NorSpMa, chr=4, pos="ELF3", trait="SurvWin2",covariate="Cytop", additive=F,family="binomial")

LG4_FrSh2_M_loc30 <- makeqtl(NorSpMa,4, 30, what="prob")
summary(LG4_FrSh2_M_loc30)
LG4_FrSh2_M_loc30_qtl <- fitqtl(NorSpMa, LG4_FrSh2_M_loc30, pheno.col="FrSh2", formula=y~Q1, method="hk", get.ests=TRUE)
summary (LG4_FrSh2_M_loc30_qtl)
adimodel(NorSpMa, chr=4, pos="EX", trait="FrSh2",covariate="Cytop", additive=F)

LG4_FrSh3_M_loc46 <- makeqtl(NorSpMa,4, 46, what="prob")
summary(LG4_FrSh3_M_loc46)
LG4_FrSh3_M_loc46_qtl <- fitqtl(NorSpMa, LG4_FrSh3_M_loc46, pheno.col="FrSh3", formula=y~Q1, method="hk", get.ests=TRUE)
summary (LG4_FrSh3_M_loc46_qtl)
adimodel(NorSpMa, chr=4, pos="TTG2", trait="FrSh3",covariate="Cytop", additive=F)

#LG5

LG5_FrSh1_M_loc52 <- makeqtl(NorSpMa,5, 52, what="prob")
summary(LG5_FrSh1_M_loc52)
LG5_FrSh1_M_loc52_qtl <- fitqtl(NorSpMa, LG5_FrSh1_M_loc52, pheno.col="FrSh1", formula=y~Q1, method="hk", get.ests=TRUE)
summary (LG5_FrSh1_M_loc52_qtl)
adimodel(NorSpMa, chr=5, pos="loc52", trait="FrSh1",covariate="Cytop", additive=F)

LG5_TotFr4_C_loc30 <- makeqtl(NorSpMa,5, 30, what="prob")
summary(LG5_TotFr4_C_loc30)
LG5_TotFr4_C_loc30_qtl <- fitqtl(NorSpMa, LG5_TotFr4_C_loc30, pheno.col="TotFr4", formula=y~Q1, method="hk", get.ests=TRUE)
summary (LG5_TotFr4_C_loc30_qtl)
adimodel(NorSpMa, chr=5, pos="loc30", trait="TotFr4",covariate="Cytop", additive=F)

#LG6

LG6_TotSh1_C_loc26 <- makeqtl(NorSpMa,6, 26, what="prob")
summary(LG6_TotSh1_C_loc26)
LG6_TotSh1_C_loc26_qtl <- fitqtl(NorSpMa, LG6_TotSh1_C_loc26, pheno.col="TotSh1", formula=y~Q1, method="hk", get.ests=TRUE)
summary (LG6_TotSh1_C_loc26_qtl)
adimodel(NorSpMa, chr=6, pos="loc26", trait="TotSh1",covariate="Cytop", additive=F)
adimodel(subset(NorSpMa,ind=Cross==0), chr=6, pos="loc26", trait="TotSh1",covariate="Unif", additive=F)
adimodel(subset(NorSpMa,ind=Cross==1), chr=6, pos="loc26", trait="TotSh1",covariate="Unif", additive=F)

#LG7

LG7_FlStart1_C_loc0 <- makeqtl(NorSpMa,7, 0, what="prob")
summary(LG7_FlStart1_C_loc0)
LG7_FlStart1_C_loc0_qtl <- fitqtl(NorSpMa, LG7_FlStart1_C_loc0, pheno.col="FlStart1", formula=y~Q1, method="hk", get.ests=TRUE)
summary (LG7_FlStart1_C_loc0_qtl)
adimodel(NorSpMa, chr=7, pos="AT4G39680", trait="FlStart1",covariate="Cytop", additive=F)
adimodel(subset(NorSpMa,ind=Cross==0), chr=7, pos="AT4G39680", trait="FlStart1",covariate="Unif", additive=F)
adimodel(subset(NorSpMa,ind=Cross==1), chr=7, pos="AT4G39680", trait="FlStart1",covariate="Unif", additive=F)

LG7_FlStart2_M_loc2 <- makeqtl(NorSpMa,7, 2, what="prob")
summary(LG7_FlStart2_M_loc2)
LG7_FlStart2_M_loc2_qtl <- fitqtl(NorSpMa, LG7_FlStart2_M_loc2, pheno.col="FlStart2", formula=y~Q1, method="hk", get.ests=TRUE)
summary (LG7_FlStart2_M_loc2_qtl)
adimodel(NorSpMa, chr=7, pos="loc2", trait="FlStart2",covariate="Cytop", additive=F)

LG7_FlStart3_M_loc2 <- makeqtl(NorSpMa,7, 2, what="prob")
summary(LG7_FlStart3_M_loc2)
LG7_FlStart3_M_loc2_qtl <- fitqtl(NorSpMa, LG7_FlStart3_M_loc2, pheno.col="FlStart3", formula=y~Q1, method="hk", get.ests=TRUE)
summary (LG7_FlStart3_M_loc2_qtl)
adimodel(NorSpMa, chr=7, pos="AP2", trait="FlStart3",covariate="Cytop", additive=F)

#LG8

LG8_FrSh1_M_loc36 <- makeqtl(NorSpMa,8, 36, what="prob")
summary(LG8_FrSh1_M_loc36)
LG8_FrSh1_M_loc36_qtl <- fitqtl(NorSpMa, LG8_FrSh1_M_loc36, pheno.col="FrSh1", formula=y~Q1, method="hk", get.ests=TRUE)
summary (LG8_FrSh1_M_loc36_qtl)
adimodel(NorSpMa, chr=8, pos="loc36", trait="FrSh1",covariate="Cytop", additive=F)

LG8_TotFr4_C_loc30 <- makeqtl(NorSpMa,8, 30, what="prob")
summary(LG8_TotFr4_C_loc30)
LG8_TotFr4_C_loc30_qtl <- fitqtl(NorSpMa, LG8_TotFr4_C_loc30, pheno.col="TotFr4", formula=y~Q1, method="hk", get.ests=TRUE)
summary (LG8_TotFr4_C_loc30_qtl)
adimodel(NorSpMa, chr=8, pos="loc30", trait="TotFr4",covariate="Cytop", additive=F)


##ADDITIVE QTL (TESTED IF QTL WITH DOMINANCE WAS FOUND IN ANOTHER ENVIRONMENT OR FOR RELATED TRAIT

#TESTING FOR SIGNIFICANCE OF QTL MAIN EFFECT AND DOMINANCE EFFECT

#LG1
LG1_TotSh3_M_loc82<- makeqtl(NorSpMa,1, 82, what="prob")
summary(LG1_TotSh3_M_loc82)
LG1_TotSh3_M_loc82_qtl <- fitqtl(NorSpMa, LG1_TotSh3_M_loc82, pheno.col="TotSh3", formula=y~Q1, method="hk", get.ests=TRUE)
summary(LG1_TotSh3_M_loc82_qtl)
adimodel(NorSpMa, chr=1, pos="loc82", trait="TotSh3",covariate="Cytop", additive=F)

LG1_FrSh1_M_loc26 <- makeqtl(NorSpMa,1, 26, what="prob")
summary(LG1_FrSh1_M_loc26)
LG1_FrSh1_M_loc26_qtl <- fitqtl(NorSpMa, LG1_FrSh1_M_loc26, pheno.col="FrSh1", formula=y~Q1, method="hk", get.ests=TRUE)
summary(LG1_FrSh1_M_loc26_qtl)
adimodel(NorSpMa, chr=1, pos="loc26", trait="FrSh1",covariate="Cytop", additive=F)

#LG2 (no QTL with dominance at genome-wide level)

#LG3 (effect for survival genome-wide significant every year)

#LG4
LG4_SurvWin2_M_loc18 <- makeqtl(NorSpMa,4, 18, what="prob")
summary(LG4_SurvWin2_M_loc18)
LG4_SurvWin2_M_loc18_qtl <- fitqtl(NorSpMa, LG4_SurvWin2_M_loc18, pheno.col="SurvWin2", formula=y~Q1, method="hk", get.ests=TRUE)
summary (LG4_SurvWin2_M_loc18_qtl)
adimodel(NorSpMa, chr=4, pos="ELF3", trait="SurvWin2",covariate="Cytop", additive=F,family="binomial")

LG4_FrSh2_M_loc30 <- makeqtl(NorSpMa,4, 30, what="prob")
summary(LG4_FrSh2_M_loc30)
LG4_FrSh2_M_loc30_qtl <- fitqtl(NorSpMa, LG4_FrSh2_M_loc30, pheno.col="FrSh2", formula=y~Q1, method="hk", get.ests=TRUE)
summary (LG4_FrSh2_M_loc30_qtl)
adimodel(NorSpMa, chr=4, pos="EX", trait="FrSh2",covariate="Cytop", additive=F)

#LG5
LG5_FrSh1_M_loc52 <- makeqtl(NorSpMa,5, 52, what="prob")
summary(LG5_FrSh1_M_loc52)
LG5_FrSh1_M_loc52_qtl <- fitqtl(NorSpMa, LG5_FrSh1_M_loc52, pheno.col="FrSh1", formula=y~Q1, method="hk", get.ests=TRUE)
summary (LG5_FrSh1_M_loc52_qtl)
adimodel(NorSpMa, chr=5, pos="loc52", trait="FrSh1",covariate="Cytop", additive=F)

LG5_TotFr4_C_loc30 <- makeqtl(NorSpMa,5, 30, what="prob")
summary(LG5_TotFr4_C_loc30)
LG5_TotFr4_C_loc30_qtl <- fitqtl(NorSpMa, LG5_TotFr4_C_loc30, pheno.col="TotFr4", formula=y~Q1, method="hk", get.ests=TRUE)
summary (LG5_TotFr4_C_loc30_qtl)
adimodel(NorSpMa, chr=5, pos="loc30", trait="TotFr4",covariate="Cytop", additive=F)

#LG6 (no putative peaks)

#LG7 (no putative peaks) 

#LG8 (no putative peaks) 


#BAYESIAN 95% INTERVALS FOR GENOME-WIDE SIGNIFICANT AND PUTATIVE QTL

#LG1
#ADDITIVE QTL
bayesint (SurvWin2.Cross.ScanAC, chr=1, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (SurvWin3.Cross.ScanAC, chr=1, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (SurvWin4.Cross.ScanAC, chr=1, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (Flow4.Cross.ScanIC-Flow4.Cross.ScanAC, chr=1, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (FrSh2.Cross.ScanAC, chr=1, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (FrSh3.Cross.ScanAC, chr=1, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (SeFrG1.Cross.ScanAC, chr=1, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (SeFrG2.Cross.ScanAC, chr=1, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (FlStart1.Scan.NP, chr=1, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (FlStart2.Scan.NP, chr=1, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)

#QTL WITH DOMINANCE
bayesint (Flow4.Cross.ScanIC-Flow4.Cross.ScanAC, chr=1, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (TotSh1.Cross.ScanAC, chr=1, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (TotSh3.Cross.ScanAC, chr=1, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (FrSh1.Cross.ScanAC, chr=1, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (FrSh2.Cross.ScanAC, chr=1, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)

#LG2
#ADDITIVE QTL
bayesint (SurvWin5.Cross.ScanAC, chr=2, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (FrSh1.Cross.ScanAC, chr=2, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (FrSh2.Cross.ScanAC, chr=2, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (TotFr5.Cross.ScanAC, chr=2, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (SeFrG1.Cross.ScanAC, chr=2, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)

#LG3
#ADDITIVE QTL
bayesint (SurvWin5.Cross.ScanIC-SurvWin5.Cross.ScanAC, chr=3, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (FlStart1.Cross.ScanAC, chr=3, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (FlStart2.Cross.ScanAC, chr=3, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (FlStart3.Cross.ScanAC, chr=3, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)

#QTL WITH DOMINANCE
bayesint (SurvWin2.Cross.ScanIC-SurvWin2.Cross.ScanAC, chr=3, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (SurvWin3.Cross.ScanIC-SurvWin3.Cross.ScanAC, chr=3, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (SurvWin4.Cross.ScanIC-SurvWin4.Cross.ScanAC, chr=3, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (SurvWin5.Cross.ScanIC-SurvWin5.Cross.ScanAC, chr=3, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)

#LG4
#ADDITIVE QTL
bayesint (SurvWin2.Cross.ScanAC, chr=4, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (SurvWin5.Cross.ScanAC, chr=4, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (FrSh2.Cross.ScanAC, chr=4, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (TotFr5.Cross.ScanIC-TotFr5.Cross.ScanAC, chr=4, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (FlStart2.Scan.NP, chr=4, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)

#QTL WITH DOMINANCE
bayesint (SurvWin4.Cross.ScanAC, chr=4, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (SurvWin5.Cross.ScanAC, chr=4, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (Flow4.Cross.ScanAC, chr=4, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (TotFr5.Cross.ScanIC-TotFr5.Cross.ScanAC, chr=4, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (SeFrG1.Cross.ScanIC-SeFrG1.Cross.ScanAC, chr=4, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)

#LG5
#ADDITIVE QTL
bayesint (FrSh1.Cross.ScanAC, chr=5, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (FrSh2.Cross.ScanIC-FrSh2.Cross.ScanAC, chr=5, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)

#QTL WITH DOMINANCE
bayesint (FrSh2.Cross.ScanIC-FrSh2.Cross.ScanAC, chr=5, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (TotFr4.Cross.ScanIC-TotFr4.Cross.ScanAC, chr=5, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)

#LG6
#ADDITIVE QTL
bayesint (TotSh1.Cross.ScanIC-TotSh1.Cross.ScanAC, chr=6, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
#QTL WITH DOMINANCE
bayesint (SurvWin3.Cross.ScanAC, chr=6, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)

#LG7
#ADDITIVE QTL
bayesint (SurvWin5.Cross.ScanAC, chr=7, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (FlStart2.Cross.ScanAC, chr=7, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)

#QTL WITH DOMINANCE
bayesint (SurvWin4.Cross.ScanAC, chr=7, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (SurvWin5.Cross.ScanAC, chr=7, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (FrSh2.Cross.ScanIC-FrSh2.Cross.ScanAC, chr=7, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)

#LG8
#ADDITIVE QTL
bayesint (SurvWin2.Cross.ScanAC, chr=8, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (SurvWin3.Cross.ScanAC, chr=8, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (SurvWin4.Cross.ScanAC, chr=8, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (SurvWin5.Cross.ScanAC, chr=8, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (FrSh1.Cross.ScanAC, chr=8, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (FrSh2.Cross.ScanAC, chr=8, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (SeFrG2.Cross.ScanAC, chr=8, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (FlStart2.Scan.NP, chr=8, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)

#QTL WITH DOMINANCE
bayesint (SurvWin4.Cross.ScanAC, chr=8, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (SurvWin5.Cross.ScanAC, chr=8, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)

#LOD PROFILE PLOTS IN THE SUPPLEMENTAL MATERIAL:

#PLOTS

plot(SurvWin2.Cross.ScanAC, col="black", lty=2, lwd=4, ylab="LOD", ylim=c(0,8), main="Survival in Norway", xlab="LG")
plot(SurvWin3.Cross.ScanAC, col="black", lty=3,lwd=4, ylab="LOD", ylim=c(0,8), add=TRUE)
plot(SurvWin4.Cross.ScanAC, col="grey50", lty=1,lwd=4, ylab="LOD", ylim=c(0,8), add=TRUE)
plot(SurvWin5.Cross.ScanAC, col="grey50", lty=2,lwd=4, ylab="LOD", ylim=c(0,8), add=TRUE)

add.threshold(SurvWin2.Cross.ScanAC, perms=SurvWin2.Cross.PermAC,alpha=0.05, col="black",lwd=4,  lty=2)
add.threshold(SurvWin3.Cross.ScanAC, perms=SurvWin3.Cross.PermAC,alpha=0.05, col="black",lwd=4,  lty=3)
add.threshold(SurvWin4.Cross.ScanAC, perms=SurvWin4.Cross.PermAC,alpha=0.05, col="grey50", lwd=4, lty=1)
add.threshold(SurvWin5.Cross.ScanAC, perms=SurvWin5.Cross.PermAC, alpha=0.05, col="grey50",lwd=4,  lty=2)

plot(SurvWin2.Cross.ScanIC-SurvWin2.Cross.ScanAC, col="black",lty=2, lwd=4,ylim=c(0,8), main="Survival in Norway", xlab="LG")
plot(SurvWin3.Cross.ScanIC-SurvWin3.Cross.ScanAC, col="black",lty=3, lwd=4,ylim=c(0,8), add=TRUE)
plot(SurvWin4.Cross.ScanIC-SurvWin4.Cross.ScanAC, col="grey50",lty=1, lwd=4,ylim=c(0,8), add=TRUE)
plot(SurvWin5.Cross.ScanIC-SurvWin5.Cross.ScanAC, col="grey50",lty=2,lwd=4, ylim=c(0,8), add=TRUE)
add.threshold(SurvWin2.Cross.ScanIC-SurvWin2.Cross.ScanAC, perms=SurvWin2.Cross.PermDiff,alpha=0.05, col="black", lwd=4,lty=2)
add.threshold(SurvWin3.Cross.ScanIC-SurvWin3.Cross.ScanAC, perms=SurvWin3.Cross.PermDiff,alpha=0.05, col="black", lwd=4,lty=3)
add.threshold(SurvWin4.Cross.ScanIC-SurvWin4.Cross.ScanAC, perms=SurvWin4.Cross.PermDiff,alpha=0.05, col="grey50", lwd=4,lty=1)
add.threshold(SurvWin5.Cross.ScanIC-SurvWin5.Cross.ScanAC, perms=SurvWin5.Cross.PermDiff,alpha=0.05, col="grey50", lwd=4,lty=2)



plot(Flow2.Cross.ScanAC, col="black", lty=2, lwd=4, ylab="LOD", ylim=c(0,6), main="Flowering % in Norway", xlab="LG")
plot(Flow3.Cross.ScanAC, col="black", lty=3,lwd=4, ylab="LOD", ylim=c(0,6), add=TRUE)
plot(Flow4.Cross.ScanAC, col="grey50", lty=1,lwd=4, ylab="LOD", ylim=c(0,6), add=TRUE)
plot(Flow5.Cross.ScanAC, col="grey50", lty=2,lwd=4, ylab="LOD", ylim=c(0,6), add=TRUE)

add.threshold(Flow2.Cross.ScanAC, perms=Flow2.Cross.PermAC,alpha=0.05, col="black",lwd=4,  lty=2)
add.threshold(Flow3.Cross.ScanAC, perms=Flow3.Cross.PermAC,alpha=0.05, col="black",lwd=4,  lty=3)
add.threshold(Flow4.Cross.ScanAC, perms=Flow4.Cross.PermAC,alpha=0.05, col="grey50", lwd=4, lty=1)
add.threshold(Flow5.Cross.ScanAC, perms=Flow5.Cross.PermAC, alpha=0.05, col="grey50",lwd=4,  lty=2)

plot(Flow2.Cross.ScanIC-Flow2.Cross.ScanAC, col="black",lty=2, lwd=4,ylim=c(0,6), main="Flowering % in Norway", xlab="LG")
plot(Flow3.Cross.ScanIC-Flow3.Cross.ScanAC, col="black",lty=3, lwd=4,ylim=c(0,6), add=TRUE)
plot(Flow4.Cross.ScanIC-Flow4.Cross.ScanAC, col="grey50",lty=1, lwd=4,ylim=c(0,6), add=TRUE)
plot(Flow5.Cross.ScanIC-Flow5.Cross.ScanAC, col="grey50",lty=2,lwd=4, ylim=c(0,6), add=TRUE)
add.threshold(Flow2.Cross.ScanIC-Flow2.Cross.ScanAC, perms=Flow2.Cross.PermDiff,alpha=0.05, col="black", lwd=4,lty=2)
add.threshold(Flow3.Cross.ScanIC-Flow3.Cross.ScanAC, perms=Flow3.Cross.PermDiff,alpha=0.05, col="black", lwd=4,lty=3)
add.threshold(Flow4.Cross.ScanIC-Flow4.Cross.ScanAC, perms=Flow4.Cross.PermDiff,alpha=0.05, col="grey50", lwd=4,lty=1)
add.threshold(Flow5.Cross.ScanIC-Flow5.Cross.ScanAC, perms=Flow5.Cross.PermDiff,alpha=0.05, col="grey50", lwd=4,lty=2)




plot(TotSh1.Cross.ScanAC, col="black", lty=1,ylab="LOD",lwd=4, ylim=c(0,4), main="# infl. shoots in Norway", xlab="LG")
plot(TotSh2.Cross.ScanAC, col="black", lty=2,ylab="LOD",lwd=4, ylim=c(0,4), add=T)
plot(TotSh3.Cross.ScanAC, col="black", lty=3,ylab="LOD", lwd=4,ylim=c(0,4), add=T)
add.threshold(TotSh1.Cross.ScanAC, perms=TotSh1.Cross.PermAC,alpha=0.05, col="black", lwd=4,lty=1)
add.threshold(TotSh2.Cross.ScanAC, perms=TotSh2.Cross.PermAC,alpha=0.05, col="black", lwd=4,lty=2)
add.threshold(TotSh3.Cross.ScanAC, perms=TotSh3.Cross.PermAC,alpha=0.05, col="black",lwd=4, lty=3)

plot(TotSh1.Cross.ScanIC-TotSh1.Cross.ScanAC, lty=1, lwd=4, ylim=c(0,4), main="# infl. shoots in Norway", xlab="LG")
plot(TotSh2.Cross.ScanIC-TotSh2.Cross.ScanAC, lty=2,lwd=4, ylim=c(0,4), add=TRUE)
plot(TotSh3.Cross.ScanIC-TotSh3.Cross.ScanAC, lty=3,lwd=4, ylim=c(0,4), add=TRUE)
add.threshold(TotSh1.Cross.ScanIC-TotSh1.Cross.ScanAC, perms=TotSh1.Cross.PermDiff,alpha=0.05, col="black",lwd=4, lty=1)
add.threshold(TotSh2.Cross.ScanIC-TotSh2.Cross.ScanAC, perms=TotSh2.Cross.PermDiff,alpha=0.05, col="black",lwd=4, lty=2)
add.threshold(TotSh3.Cross.ScanIC-TotSh3.Cross.ScanAC, perms=TotSh3.Cross.PermDiff,alpha=0.05, col="black", lwd=4,lty=3)


plot(FrSh1.Cross.ScanAC, col="black", lty=1,ylab="LOD", lwd=4, ylim=c(0,10), main="# fruits/infl. in Norway", xlab="LG")
plot(FrSh2.Cross.ScanAC, col="black", lty=2,ylab="LOD", lwd=4, ylim=c(0,10), add=T)
plot(FrSh3.Cross.ScanAC, col="black", lty=3,ylab="LOD", lwd=4, ylim=c(0,10), add=T)
add.threshold(FrSh1.Cross.ScanAC, perms=FrSh1.Cross.PermAC,alpha=0.05, col="black",lwd=4, lty=1)
add.threshold(FrSh2.Cross.ScanAC, perms=FrSh2.Cross.PermAC,alpha=0.05, col="black",lwd=4, lty=2)
add.threshold(FrSh3.Cross.ScanAC, perms=FrSh3.Cross.PermAC,alpha=0.05, col="black",lwd=4, lty=3)

plot(FrSh1.Cross.ScanIC-FrSh1.Cross.ScanAC, lwd=4,lty=1, ylim=c(0,4), main="# fruits/infl. in Norway", xlab="LG")
plot(FrSh2.Cross.ScanIC-FrSh2.Cross.ScanAC,lwd=4, lty=2, ylim=c(0,4), add=TRUE)
plot(FrSh3.Cross.ScanIC-FrSh3.Cross.ScanAC,lwd=4 ,lty=3, ylim=c(0,4), add=TRUE)
add.threshold(FrSh1.Cross.ScanIC-FrSh1.Cross.ScanAC, perms=FrSh1.Cross.PermDiff,alpha=0.05, col="black", lwd=4,lty=1)
add.threshold(FrSh2.Cross.ScanIC-FrSh2.Cross.ScanAC, perms=FrSh2.Cross.PermDiff,alpha=0.05, col="black", lwd=4,lty=2)
add.threshold(FrSh3.Cross.ScanIC-FrSh3.Cross.ScanAC, perms=FrSh3.Cross.PermDiff,alpha=0.05, col="black",lwd=4, lty=3)

plot(TotFr4.Cross.ScanAC, col="grey50", lty=1,ylab="LOD", lwd=4,ylim=c(0,5), main="# fruits in Norway", xlab="LG")
plot(TotFr5.Cross.ScanAC, col="grey50", lty=2,ylab="LOD", lwd=4,ylim=c(0,5), add=T)
add.threshold(TotFr4.Cross.ScanAC, perms=TotFr4.Cross.PermAC,alpha=0.05, col="grey50",lwd=4, lty=1)
add.threshold(TotFr5.Cross.ScanAC, perms=TotFr5.Cross.PermAC,alpha=0.05, col="grey50",lwd=4, lty=2)

plot(TotFr4.Cross.ScanIC-TotFr4.Cross.ScanAC, col="grey50",lty=1, lwd=4,ylim=c(0,5), main="# fruits in Norway", xlab="LG")
plot(TotFr5.Cross.ScanIC-TotFr5.Cross.ScanAC, col="grey50",lty=2, lwd=4,ylim=c(0,5), add=TRUE)
add.threshold(TotFr4.Cross.ScanIC-TotFr4.Cross.ScanAC, perms=TotFr4.Cross.PermDiff,alpha=0.05, col="grey50", lwd=4,lty=1)
add.threshold(TotFr5.Cross.ScanIC-TotFr5.Cross.ScanAC, perms=TotFr5.Cross.PermDiff,alpha=0.05, col="grey50",lwd=4, lty=2)


plot(SeFrG1.Cross.ScanAC, col="black", lty=1,ylab="LOD", lwd=4,ylim=c(0,7), main="# seeds/fruit in Norway", xlab="LG")
plot(SeFrG2.Cross.ScanAC, col="black", lty=2,ylab="LOD",lwd=4, ylim=c(0,7), add=T)
plot(SeFrG3.Cross.ScanAC, col="black", lty=3,ylab="LOD", lwd=4,ylim=c(0,7), add=T)
add.threshold(SeFrG1.Cross.ScanAC, perms=SeFrG1.Cross.PermAC,alpha=0.05, col="black",lwd=4, lty=1)
add.threshold(SeFrG2.Cross.ScanAC, perms=SeFrG2.Cross.PermAC,alpha=0.05, col="black",lwd=4, lty=2)
add.threshold(SeFrG3.Cross.ScanAC, perms=SeFrG3.Cross.PermAC,alpha=0.05, col="black",lwd=4, lty=3)



plot(SeFrG1.Cross.ScanIC-SeFrG1.Cross.ScanAC,lwd=4, lty=1,ylim=c(0,7), main="# seeds/fruit in Norway", xlab="LG")
plot(SeFrG2.Cross.ScanIC-SeFrG2.Cross.ScanAC,lwd=4, lty=2,ylim=c(0,7), add=TRUE)
plot(SeFrG3.Cross.ScanIC-SeFrG3.Cross.ScanAC,lwd=4, lty=3,ylim=c(0,7), add=TRUE)
add.threshold(SeFrG1.Cross.ScanIC-SeFrG1.Cross.ScanAC, perms=SeFrG1.Cross.PermDiff,alpha=0.05, col="black",lwd=4, lty=1)
add.threshold(SeFrG2.Cross.ScanIC-SeFrG2.Cross.ScanAC, perms=SeFrG2.Cross.PermDiff,alpha=0.05, col="black", lwd=4,lty=2)
add.threshold(SeFrG3.Cross.ScanIC-SeFrG3.Cross.ScanAC, perms=SeFrG3.Cross.PermDiff,alpha=0.05, col="black",lwd=4, lty=3)



plot(FlStart1.Cross.ScanAC, col="black", lty=1,ylab="LOD", lwd=4, ylim=c(0,5), main="flowering start in Norway", xlab="LG")
plot(FlStart2.Cross.ScanAC, col="black", lty=2,ylab="LOD", lwd=4, ylim=c(0,5), add=TRUE)
plot(FlStart3.Cross.ScanAC, col="black", lty=3,ylab="LOD", lwd=4, ylim=c(0,5), add=TRUE)
add.threshold(FlStart1.Cross.ScanAC, perms=FlStart1.Cross.PermAC,alpha=0.05, col="black", lwd=4, lty=1)
add.threshold(FlStart2.Cross.ScanAC, perms=FlStart2.Cross.PermAC,alpha=0.05, col="black", lwd=4, lty=2)
add.threshold(FlStart3.Cross.ScanAC, perms=FlStart3.Cross.PermAC,alpha=0.05, col="black", lwd=4, lty=3)

plot(FlStart1.Cross.ScanIC-FlStart1.Cross.ScanAC, lwd=4, ylim=c(0,5), lty=1, main="flowering start in Norway", xlab="LG")
plot(FlStart2.Cross.ScanIC-FlStart2.Cross.ScanAC, lwd=4, ylim=c(0,5), lty=2, add=TRUE)
plot(FlStart3.Cross.ScanIC-FlStart3.Cross.ScanAC, lwd=4, ylim=c(0,5), lty=3, add=TRUE)
add.threshold(FlStart1.Cross.ScanIC-FlStart1.Cross.ScanAC, perms=FlStart1.Cross.PermDiff,alpha=0.05, col="black", lwd=4, lty=1)
add.threshold(FlStart2.Cross.ScanIC-FlStart2.Cross.ScanAC, perms=FlStart2.Cross.PermDiff,alpha=0.05, col="black", lwd=4, lty=2)
add.threshold(FlStart3.Cross.ScanIC-FlStart3.Cross.ScanAC, perms=FlStart3.Cross.PermDiff,alpha=0.05, col="black", lwd=4, lty=3)

plot(FlStart1.Scan.NP, col="black", lty=1,ylab="LOD", lwd=4, ylim=c(0,7), main="flowering start in Norway", xlab="LG")
plot(FlStart2.Scan.NP, col="black", lty=2,ylab="LOD", lwd=4, ylim=c(0,7), add=TRUE)
plot(FlStart3.Scan.NP, col="black", lty=3,ylab="LOD", lwd=4, ylim=c(0,7), add=TRUE)
add.threshold(FlStart1.Scan.NP, perms=FlStart1.Perm.NP,alpha=0.05, col="black", lwd=4, lty=1)
add.threshold(FlStart2.Scan.NP, perms=FlStart2.Perm.NP,alpha=0.05, col="black", lwd=4, lty=2)
add.threshold(FlStart3.Scan.NP, perms=FlStart3.Perm.NP,alpha=0.05, col="black", lwd=4, lty=3)


